@@ -4,3 +4,7 @@ from clint.exceptions import ClintException
 
 class HookException(ClintException):
     """Generic hook exception."""
+
+
+class ResultException(ClintException):
+    """Generic result exception."""
